@@ -394,9 +394,9 @@ profile_list_delete_button_clicked_cb (GtkWidget *button,
                                    name);
 
   gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-                          _("_Cancel"),
+                          GTK_STOCK_CANCEL,
                           GTK_RESPONSE_REJECT,
-                          _("_Delete"),
+                          GTK_STOCK_DELETE,
                           GTK_RESPONSE_ACCEPT,
                           NULL);
   gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
@@ -589,7 +589,6 @@ terminal_prefs_show_preferences (GtkWindow *transient_parent,
   GtkWidget *dialog, *tree_view;
   GtkWidget *show_menubar_button, *disable_mnemonics_button, *disable_menu_accel_button;
   GtkWidget *tree_view_container, *new_button, *edit_button, *clone_button, *remove_button;
-  GtkWidget *dark_theme_button, *new_terminal_mode_combo;
   GtkWidget *default_hbox, *default_label;
   GtkTreeSelection *selection;
   GSettings *settings;
@@ -610,8 +609,6 @@ terminal_prefs_show_preferences (GtkWindow *transient_parent,
                                        "preferences-dialog",
                                        "preferences-dialog", &dialog,
                                        "default-show-menubar-checkbutton", &show_menubar_button,
-                                       "dark-theme-checkbutton", &dark_theme_button,
-                                       "new-terminal-mode-combobox", &new_terminal_mode_combo,
                                        "disable-mnemonics-checkbutton", &disable_mnemonics_button,
                                        "disable-menu-accel-checkbutton", &disable_menu_accel_button,
                                        "accelerators-treeview", &tree_view,
@@ -639,18 +636,6 @@ terminal_prefs_show_preferences (GtkWindow *transient_parent,
                    "active",
                    G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
 
-  g_settings_bind (settings,
-                   TERMINAL_SETTING_DARK_THEME_KEY,
-                   dark_theme_button,
-                   "active",
-                   G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
-
-  g_settings_bind (settings,
-                   TERMINAL_SETTING_NEW_TERMINAL_MODE_KEY,
-                   new_terminal_mode_combo,
-                   "active-id",
-                   G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
-
   /* Keybindings tab */
 
   g_settings_bind (settings,
