@@ -72,8 +72,6 @@ struct _TerminalScreenClass
 
 GType terminal_screen_get_type (void) G_GNUC_CONST;
 
-const char *terminal_screen_get_uuid (TerminalScreen *screen);
-
 TerminalScreen *terminal_screen_new (GSettings       *profile,
                                      char           **override_command,
                                      const char      *title,
@@ -100,15 +98,19 @@ void         terminal_screen_set_initial_environment (TerminalScreen  *screen,
                                                       char           **argv);
 char **      terminal_screen_get_initial_environment (TerminalScreen  *screen);
 
-const char *terminal_screen_get_user_title     (TerminalScreen *screen);
+const char* terminal_screen_get_raw_title      (TerminalScreen *screen);
 const char* terminal_screen_get_title          (TerminalScreen *screen);
 const char* terminal_screen_get_icon_title     (TerminalScreen *screen);
 gboolean    terminal_screen_get_icon_title_set (TerminalScreen *screen);
-char *      terminal_screen_get_description    (TerminalScreen *screen);
 
 void terminal_screen_set_user_title (TerminalScreen *screen,
                                      const char *text);
 
+void        terminal_screen_set_override_title     (TerminalScreen *screen,
+                                                    const char     *title);
+
+const char *terminal_screen_get_dynamic_title      (TerminalScreen *screen);
+const char *terminal_screen_get_dynamic_icon_title (TerminalScreen *screen);
 
 char *terminal_screen_get_current_dir (TerminalScreen *screen);
 
@@ -146,7 +148,7 @@ gboolean terminal_screen_has_foreground_process (TerminalScreen *screen);
 
 struct _TerminalScreenPopupInfo {
   int ref_count;
-  TerminalWindow *window;
+  GWeakRef window_weak_ref;
   TerminalScreen *screen;
   char *string;
   TerminalURLFlavour flavour;
@@ -159,6 +161,8 @@ TerminalScreenPopupInfo *terminal_screen_popup_info_ref (TerminalScreenPopupInfo
 
 void terminal_screen_popup_info_unref (TerminalScreenPopupInfo *info);
 
+TerminalWindow *terminal_screen_popup_info_ref_window (TerminalScreenPopupInfo *info);
+
 G_END_DECLS
 
 #endif /* TERMINAL_SCREEN_H */
